@@ -52,7 +52,7 @@ class keyframe:
 		""" Generate the MLT keyframe string for the XML: 0=0%,0%:100%x100%:100; -1=0%,0%:100%x100%:100 """
 		
 		# generate string
-		output = "%d=%s%%,%s%%:%s%%x%s%%:%s; " % (self.frame, locale.str(self.x), locale.str(self.y), locale.str(self.width), locale.str(self.height), locale.str(self.alpha * 100.0))
+		output = "%d=%s%%,%s%%:%s%%x%s%%:%s; " % (int(round(self.frame)), locale.str(self.x), locale.str(self.y), locale.str(self.width), locale.str(self.height), locale.str(self.alpha * 100.0))
 		
 		# return string
 		return output
