@@ -114,6 +114,9 @@ class player ( threading.Thread ):
 	
 			# Create the producer
 			self.p = mlt.Producer( self.profile, 'xml:%s' % self.file_name)
+			if self.p.is_valid() == False:
+				print "ERROR WITH %s" % self.file_name
+				return
 
 			# get export file path
 			folder = self.render_options["folder"]
@@ -171,6 +174,9 @@ class player ( threading.Thread ):
 			
 			# Create the producer
 			self.p = mlt.Producer( self.profile, 'xml:%s' % self.file_name)
+			if self.p.is_valid() == False:
+				print "ERROR WITH %s" % self.file_name
+				return
 
 			# refresh sdl and pause video
 			self.pause()
