@@ -142,9 +142,23 @@ class frmTitles(SimpleGtkBuilderApp):
 		# get the model and iterator of the project type dropdown box
 		model = self.cmbTemplate.get_model()
 		iter = model.get_iter_first()
+		
+		# Find initial title
+		while iter:
+			# get the value of each item in the dropdown
+			value = model.get_value(iter, 0)
+			
+			# check for the matching value
+			if value == "Gold 2":			
+				
+				# set the item as active
+				self.cmbTemplate.set_active_iter(iter)
+				break
+		
+			# get the next item in the list
+			iter = model.iter_next(iter)
 
-		# set the item as active
-		self.cmbTemplate.set_active_iter(iter)
+		# bind signal
 		self.on_cmbTemplate_changed(self.cmbTemplate)
 		
 
