@@ -489,7 +489,7 @@ class Settings:
 							element[0].appendChild(txt)
 						else:
 							# update existing text node
-							element[0].childNodes[0].data = section_dict[key]
+							element[0].childNodes[0].data = str(section_dict[key])
 					else:
 						#there is no matching element in the xml, 
 						#we need to add one
